/**
* PLEASE DO NOT MODIFY THIS FILE. WORK ON THE ES6 VERSION.
* OTHERWISE YOUR CHANGES WILL BE REPLACED ON THE NEXT BUILD.
**/

/**
 * @copyright  Copyright (C) 2005 - 2019 Open Source Matters, Inc. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 *
 * @since   4.0.0
 */

/**
 * Joomla pagination web component
 *
 * More info about Web Component
 * https://developer.mozilla.org/en-US/docs/Web/Web_Components
 *
 * @param   string  href        By this attribute anchor a tag will get href value <a href="href">
 * @param   string  text        By this attribute anchor a tag will
 *                              get innertext <a href="href">text</a>
 * @param   string  value       By this attribute anchor a tag will
 *                              get value <a value="12"></a>
 * @param   string  class       Add custom class
 * @param   string  activeClass Add active item class
 */
(Joomla => {
  class JoomlaPagination extends HTMLElement {
    constructor() {
      super();

      if (!Joomla) {
        throw new Error('Joomla API not properly initialised');
      }

      this.keyCode = {
        TAB: 9,
        ESC: 27
      };
      this.defaultSettings = {
        totalVisible: 10,
        resultMsg: '',
        nextText: 'Next',
        nextIcon: '>',
        prevText: 'Prev',
        prevIcon: '<',
        firstText: 'First',
        firstIcon: '<<',
        lastText: 'Last',
        lastIcon: '>>',
        navBtnsState: 'icon',
        // allowed values are ['icon', 'text', 'text-icon'],
        disableBtns: [],
        // this allowes disable the navigation buttons
        // if anywant wants, allowed texts [next, prev, first, last]
        limit: 10,
        // how many steps it will go after clicking next
        inputSelector: '#list_limit',
        // the hidden input field name
        formSelector: '#adminForm',
        // the form id
        pagination: false
      };
      this.windowHeight = window.innerHeight;
      this.nextPage = this.nextPage.bind(this);
      this.prevPage = this.prevPage.bind(this);
      this.goToFirstPage = this.goToFirstPage.bind(this);
      this.goToLastPage = this.goToLastPage.bind(this);
      this.resizeWindow = this.resizeWindow.bind(this);
      this.resizeTimer = null;
      this.dotItems = [];
      this.disableNext = false;
      this.disableLast = false;
      this.disableFirst = false;
      this.disablePrev = false;
      this.currentItemIndex = 0;

      if (window.innerWidth >= 180) {
        this.pageCount = Math.floor((window.innerWidth - 180) / 45);
      } else {
        this.pageCount = Math.floor(window.innerWidth / 45);
      }

      this.options = {};
      this.rawItems = this.getAllSiblings();
      this.listItems = this.getAllSiblings();
      this.removeRawElements();
      this.preparePaginationContainer();
    }
    /**
     * Getter methods
     */


    get customClass() {
      return this.getAttribute('class');
    }

    get totalVisible() {
      return this.getAttribute('total-visible');
    }

    get resultMsg() {
      return this.getAttribute('result-msg');
    }

    get nextText() {
      return this.getAttribute('next-text');
    }

    get nextIcon() {
      return this.getAttribute('next-icon');
    }

    get prevText() {
      return this.getAttribute('prev-text');
    }

    get prevIcon() {
      return this.getAttribute('prev-icon');
    }

    get firstText() {
      return this.getAttribute('first-text');
    }

    get firstIcon() {
      return this.getAttribute('first-icon');
    }

    get lastText() {
      return this.getAttribute('last-text');
    }

    get lastIcon() {
      return this.getAttribute('last-icon');
    }

    get navBtnsState() {
      return this.getAttribute('navbtns-state');
    }

    get disableBtns() {
      return this.getAttribute('disable-btns');
    }

    get limit() {
      return this.getAttribute('limit');
    }

    get inputSelector() {
      return this.getAttribute('input-selector');
    }

    get formSelector() {
      return this.getAttribute('form-selector');
    }

    get pagination() {
      return this.getAttribute('pagination');
    }

    preparePaginationContainer() {
      this.pageNav = JoomlaPagination.createDOMElement('nav', {
        class: 'pagination-navigation',
        role: 'navigation',
        'aria-label': 'Pagination',
        tabindex: '-1'
      });
      this.pageLabel = JoomlaPagination.createDOMElement('span', {
        class: 'pagination-label d-none d-sm-block'
      });
      this.pageUl = JoomlaPagination.createDOMElement('ul', {
        class: 'pagination-list'
      });
      this.pageNav.appendChild(this.pageLabel);
      this.pageNav.appendChild(this.pageUl);
      this.appendChild(this.pageNav);
    }
    /**
     * Get all direct children elements of joomla-pagination
     */


    getAllSiblings() {
      const result = [];
      let index = 0;
      let node = this.firstChild;

      while (node) {
        if (node !== this && node.nodeType === Node.ELEMENT_NODE) {
          node.removeAttribute('style');
          result.push(node);

          if (node.classList.contains('active')) {
            this.currentItemIndex = index - 1;
          }
        }

        index += 1;
        node = node.nextElementSibling || node.nextSibling;
      }

      return result;
    }

    removeRawElements() {
      while (this.firstChild) this.removeChild(this.firstChild);
    }

    static clearChildren(element) {
      while (element.firstChild) {
        element.removeChild(element.firstChild);
      }
    }

    removeActiveElement() {
      for (let i = 0, l = this.rawItems.length; i < l; i += 1) {
        if (this.rawItems[i].classList.contains('active')) {
          this.rawItems[i].classList.remove('active');
          this.rawItems[i].removeAttribute('aria-current');
          break;
        }
      }
    }

    setAsActiveElement(index) {
      this.rawItems[index].classList.add('active');
      this.rawItems[index].setAttribute('aria-current', true);
      this.rawItems[index].setAttribute('aria-label', "Page ".concat(index + 1));
    }

    submitLimitForm() {
      this.inputField.value = this.rawItems[this.currentItemIndex].value;
      this.adminForm.submit();
    }

    submitPaginationForm() {
      // eslint-disable-next-line max-len
      this.inputField.value = parseInt(this.options.limit, 10) * parseInt(this.currentItemIndex, 10);
      this.adminForm.submit();
    }

    static createRange(start, end) {
      const arr = [];
      if (start > end) return arr;

      for (let i = start; i <= end; i += 1) {
        arr.push(i);
      }

      return arr;
    }

    static generatePaginationList(current, total, visibleLength) {
      const flag = visibleLength % 2 === 0 ? 1 : 0;
      const head = Math.floor(visibleLength / 2);
      const tail = total - head + 1;

      if (total <= visibleLength) {
        return JoomlaPagination.createRange(1, total);
      }

      if (visibleLength <= 4) {
        return [1, current, total];
      }

      if (current > head && current < tail) {
        const start = current - head + 2;
        const end = current + head - 2 - flag;
        return [1, '...', ...JoomlaPagination.createRange(start, end), '...', total];
      }

      if (current === head) {
        const end = current + head - 1 - flag;
        return [...JoomlaPagination.createRange(1, end), '...', total];
      }

      if (current === tail) {
        const start = current - head + 1;
        return [1, '...', ...JoomlaPagination.createRange(start, total)];
      }

      return [...JoomlaPagination.createRange(1, head), '...', ...JoomlaPagination.createRange(tail, total)];
    }

    renderPagination(current, total) {
      // enable disable navigation buttons
      if (this.options.resultMsg) {
        this.pageLabel.innerHTML = this.options.resultMsg;
      }

      if (current === 0) {
        this.disablePrev = true;
        this.disableFirst = true;
        this.disableNext = false;
        this.disableLast = false;
      } else if (current === total - 1) {
        this.disablePrev = false;
        this.disableFirst = false;
        this.disableNext = true;
        this.disableLast = true;
      } else {
        this.disablePrev = false;
        this.disableFirst = false;
        this.disableNext = false;
        this.disableLast = false;
      }

      JoomlaPagination.clearChildren(this.pageUl);
      this.removeActiveElement();
      const visibleLength = (this.options.totalVisible > this.pageCount ? this.pageCount : this.options.totalVisible) || this.pageCount;
      const paginationArray = JoomlaPagination.generatePaginationList(this.currentItemIndex + 1, this.rawItems.length, visibleLength);
      this.dotItems = [];

      if (paginationArray.length > 0) {
        paginationArray.forEach((itemIndex, index) => {
          if (itemIndex !== '...') {
            if (itemIndex - 1 !== this.currentItemIndex) {
              this.rawItems[itemIndex - 1].setAttribute('aria-label', "Go to page ".concat(itemIndex));
            }

            this.pageUl.appendChild(this.rawItems[itemIndex - 1]);
          } else {
            const dotItem = JoomlaPagination.createDOMElement('li', {
              class: 'pagination-item dot-item'
            }, '...');
            const dotItemObject = {
              item: dotItem,
              left: paginationArray[index - 1],
              right: paginationArray[index + 1]
            };
            this.dotItems.push(dotItemObject);
            this.pageUl.appendChild(dotItem);
          }
        });
        this.setAsActiveElement(current);
        this.createNavigationButtons();
      }

      this.getDotItemsHiddenList();
    }

    getDotItemsHiddenList() {
      if (this.dotItems.length) {
        this.dotItems.forEach(item => {
          item.item.addEventListener('click', event => this.handleDotItemClick(event, item.left, item.right), false);
        });
      }
    }

    handleDotItemClick(event, start, end) {
      event.preventDefault();
      const dotElements = document.querySelector(".dot-item-".concat(start));
      JoomlaPagination.clearDropdown();

      if (dotElements) {
        return;
      }

      const list = JoomlaPagination.createRange(start + 1, end - 1);
      const clientRect = event.target.getBoundingClientRect();
      const style = "left: ".concat(clientRect.left, "px; top: ").concat(clientRect.top + clientRect.height, "px");

      if (list.length > 0) {
        const dotItemsUl = JoomlaPagination.createDOMElement('ul', {
          class: "dot-item-list dot-item-".concat(start),
          style
        });
        list.forEach(item => {
          dotItemsUl.appendChild(this.rawItems[item - 1]);
        });
        this.appendChild(dotItemsUl);
      }
    }

    resizeWindow() {
      this.resizeTimer = setTimeout(() => {
        if (window.innerHeight !== this.windowHeight) return;
        let elWidth = window.innerWidth;

        if (window.innerWidth >= 180) {
          elWidth = window.innerWidth - 180;
        }

        this.pageCount = Math.floor(elWidth / 45);
        this.renderPagination(this.currentItemIndex, this.rawItems.length);
      }, 1000);
    }

    connectedCallback() {
      // const paginationLength = this.getAllSiblings();
      const extendedSettings = {};
      if (this.totalVisible !== null) extendedSettings.totalVisible = this.totalVisible;
      if (this.resultMsg !== null) extendedSettings.resultMsg = this.resultMsg;
      if (this.nextText !== null) extendedSettings.nextText = this.nextText;
      if (this.nextIcon !== null) extendedSettings.nextIcon = this.nextIcon;
      if (this.prevText !== null) extendedSettings.prevText = this.prevText;
      if (this.prevIcon !== null) extendedSettings.prevIcon = this.prevIcon;
      if (this.firstText !== null) extendedSettings.firstText = this.firstText;
      if (this.firstIcon !== null) extendedSettings.firstIcon = this.firstIcon;
      if (this.lastText !== null) extendedSettings.lastText = this.lastText;
      if (this.lastIcon !== null) extendedSettings.lastIcon = this.lastIcon;
      if (this.navBtnsState !== null) extendedSettings.navBtnsState = this.navBtnsState;
      if (this.disableBtns !== null) extendedSettings.disableBtns = this.disableBtns.split(',').map(btn => btn.trim());
      if (this.inputSelector !== null) extendedSettings.inputSelector = this.inputSelector;
      if (this.formSelector !== null) extendedSettings.formSelector = this.formSelector;
      if (this.limit !== null) extendedSettings.limit = this.limit;
      if (this.pagination !== null) extendedSettings.pagination = this.pagination === 'true' || this.pagination === '1';
      this.options = { ...this.defaultSettings,
        ...extendedSettings
      };
      this.inputField = document.querySelector("".concat(this.options.inputSelector));
      this.adminForm = document.querySelector("".concat(this.options.formSelector));
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      this.clickHandlers();
      window.addEventListener('resize', this.resizeWindow, false);
      document.querySelector('html,body').addEventListener('click', JoomlaPagination.closeDropdown, false);
    } // lifecycle hook


    disconnectedCallback() {
      this.nextBtn.removeEventListener('click', this.nextPage);
      this.prevBtn.removeEventListener('click', this.prevPage);
      this.firstBtn.removeEventListener('click', this.goToFirstPage);
      this.lastBtn.removeEventListener('click', this.goToLastPage);
      if (this.resizeTimer) clearTimeout(this.resizeTimer);
      if (this.dotItems) this.dotItems.forEach(elem => {
        elem.removeEventListener('click', this);
      });
      document.querySelector('html,body').removeEventListener('click', JoomlaPagination.closeDropdown);
      window.removeEventListener('resize', this.resizeWindow, false);
    }
    /**
       * Create a HTMLElement
       * @param {string} tagName      - e.g. div, strong, span etc.
       * @param {object} attr         - element attribute object
       * @param {string} innerHTML    - text to elements innerHTML
       *
       * @return {HTMLElement}
       */


    static createDOMElement(tag, attributes = {}, text = '') {
      const tagName = typeof tag === 'string' && tag.length > 0 ? tag : 'div';
      const attr = typeof attributes === 'object' && Object.keys(attributes).length ? attributes : false;
      const innerHTML = typeof text === 'string' && text.length > 0 ? text : false; // IF tag name given then create element, otherwise create element div

      const el = document.createElement(tagName); // If attributes given then set attributes for the element

      if (attr) {
        Object.keys(attr).forEach(key => {
          el.setAttribute(key, attr[key]);
        });
      } // Add inner HTML


      if (innerHTML) {
        el.innerHTML = innerHTML;
      }

      return el;
    }

    createNavigationButtons() {
      // creating navigation buttons
      const navBtns = {
        next: {
          text: this.options.nextText,
          icon: this.options.nextIcon,
          position: 'right',
          isShown: this.options.disableBtns.indexOf('next') > -1
        },
        last: {
          text: this.options.lastText,
          icon: this.options.lastIcon,
          position: 'right',
          isShown: this.options.disableBtns.indexOf('last') > -1
        },
        prev: {
          text: this.options.prevText,
          icon: this.options.prevIcon,
          position: 'left',
          isShown: this.options.disableBtns.indexOf('prev') > -1
        },
        first: {
          text: this.options.firstText,
          icon: this.options.firstIcon,
          position: 'left',
          isShown: this.options.disableBtns.indexOf('first') > -1
        }
      };
      this.nextBtn = JoomlaPagination.createDOMElement('li', {
        class: "pagination-item is-next-btn ".concat(this.disableNext ? 'disabled' : '')
      }, this.generateNavBtnsText(navBtns.next));
      this.prevBtn = JoomlaPagination.createDOMElement('li', {
        class: "pagination-item is-prev-btn ".concat(this.disablePrev ? 'disabled' : '')
      }, this.generateNavBtnsText(navBtns.prev));
      this.firstBtn = JoomlaPagination.createDOMElement('li', {
        class: "pagination-item is-first-btn ".concat(this.disableFirst ? 'disabled' : '')
      }, this.generateNavBtnsText(navBtns.first));
      this.lastBtn = JoomlaPagination.createDOMElement('li', {
        class: "pagination-item is-last-btn ".concat(this.disableLast ? 'disabled' : '')
      }, this.generateNavBtnsText(navBtns.last));
      if (!navBtns.next.isShown) this.pageUl.appendChild(this.nextBtn);
      if (!navBtns.last.isShown) this.pageUl.appendChild(this.lastBtn);
      if (!navBtns.prev.isShown) this.pageUl.insertBefore(this.prevBtn, this.pageUl.firstChild);
      if (!navBtns.first.isShown) this.pageUl.insertBefore(this.firstBtn, this.pageUl.firstChild);
      if (!this.disableNext) this.nextBtn.addEventListener('click', this.nextPage, false);
      if (!this.disablePrev) this.prevBtn.addEventListener('click', this.prevPage, false);
      if (!this.disableFirst) this.firstBtn.addEventListener('click', this.goToFirstPage, false);
      if (!this.disableLast) this.lastBtn.addEventListener('click', this.goToLastPage, false);
    }

    generateNavBtnsText(navBtn) {
      let navBtnText = '';

      switch (this.options.navBtnsState) {
        case 'icon':
          navBtnText = "".concat(navBtn.icon.length <= 2 ? navBtn.icon : "<span class=\"".concat(navBtn.icon, "\"></span>"));
          break;

        case 'text':
          navBtnText = "".concat(navBtn.text);
          break;

        case 'text-icon':
          navBtnText = "".concat(navBtn.position === 'left' ? "".concat(navBtn.icon.length <= 2 ? navBtn.icon : "<span class=\"".concat(navBtn.icon, "\"></span>"), " ").concat(navBtn.text) : "".concat(navBtn.text, " ").concat(navBtn.icon.length <= 2 ? navBtn.icon : "<span class=\"".concat(navBtn.icon, "\"></span>")));
          break;

        default:
          navBtnText = "".concat(navBtn.icon.length <= 2 ? navBtn.icon : "<span class=\"".concat(navBtn.icon, "\"></span>"));
      }

      return navBtnText;
    }

    static clearDropdown() {
      document.querySelectorAll('.dot-item-list').forEach(elem => {
        elem.parentNode.removeChild(elem);
      });
    }

    static closeDropdown(event) {
      if (event.target.classList.contains('dot-item') === false) {
        JoomlaPagination.clearDropdown();
      }
    }

    clickHandlers() {
      if (this.listItems) {
        this.rawItems.forEach((elem, index) => {
          elem.addEventListener('click', event => this.goToPage(event, index), false);
        });
      }
    }

    nextPage(event) {
      event.preventDefault();
      if (this.currentItemIndex < this.rawItems.length - 1) this.currentItemIndex += 1;
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      JoomlaPagination.clearDropdown();
      if (this.options.pagination) this.submitPaginationForm();else this.submitLimitForm();
    }

    prevPage(event) {
      event.preventDefault();
      if (this.currentItemIndex > 0) this.currentItemIndex -= 1;
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      JoomlaPagination.clearDropdown();
      if (this.options.pagination) this.submitPaginationForm();else this.submitLimitForm();
    }

    goToLastPage(event) {
      event.preventDefault();
      this.currentItemIndex = this.rawItems.length - 1;
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      JoomlaPagination.clearDropdown();
      if (this.options.pagination) this.submitPaginationForm();else this.submitLimitForm();
    }

    goToFirstPage(event) {
      event.preventDefault();
      this.currentItemIndex = 0;
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      JoomlaPagination.clearDropdown();
      if (this.options.pagination) this.submitPaginationForm();else this.submitLimitForm();
    }

    goToPage(event, pageIndex) {
      event.preventDefault();
      this.currentItemIndex = pageIndex;
      this.renderPagination(this.currentItemIndex, this.rawItems.length);
      JoomlaPagination.clearDropdown();
      if (this.options.pagination) this.submitPaginationForm();else this.submitLimitForm();
    }

  }

  customElements.define('joomla-pagination', JoomlaPagination);
})(Joomla);